@@ -5,6 +5,10 @@ class TNZAPI():
     def __init__(self, **kwargs):
         for key, value in kwargs.items():
 
+            if key == "AuthToken":
+                self.AuthToken = _config.__AuthToken__ = value
+                _config.__APIHeaders__["Authorization"] = f"Basic {self.AuthToken}"
+
             if key == "Sender":
                 self.Sender = _config.__Sender__ = value
 
