@@ -3,6 +3,7 @@ from tnzapi.base.functions import Functions
 
 class Common:
 
+    AuthToken       = _config.__AuthToken__
     Sender          = _config.__Sender__
     APIKey          = _config.__APIKey__
     APIVersion      = _config.__APIVersion__
@@ -14,6 +15,7 @@ class Common:
     """ Constructor """
     def __init__(self,kwargs):
 
+        self.AuthToken       = _config.__AuthToken__
         self.Sender          = _config.__Sender__
         self.APIKey          = _config.__APIKey__
         self.APIVersion      = _config.__APIVersion__
@@ -26,17 +28,27 @@ class Common:
 
     """ Destructor """
     def __del__(self):
-        self.Sender          = ""
-        self.APIKey          = ""
-        self.APIVersion      = ""
-        self.APIURL          = ""
-        self.APIHeaders      = ""
+        self.AuthToken      = ""
+        self.Sender         = ""
+        self.APIKey         = ""
+        self.APIVersion     = ""
+        self.APIURL         = ""
+        self.APIHeaders     = ""
 
-        self.MessageID       = ""
+        self.MessageID      = ""
 
     """ Set Args """
     def SetArgsCommon(self, kwargs):
 
+        #
+        # AuthToken / Send / APIKey can be overriden in the TNZAPI.Get.xxx() functions
+        # Default initialization happens in /__init__.py
+        #
+
+        if "AuthToken" in kwargs:
+            self.AuthToken = _config.__AuthToken__ = kwargs.pop("AuthToken")
+            self.APIHeaders["Authorization"] = _config.__APIHeaders__["Authorization"] = f"Basic {self.AuthToken}"
+
         if "Sender" in kwargs:
             self.Sender = _config.__Sender__ = kwargs.pop("Sender")
 
