@@ -28,11 +28,25 @@ class Result(Common):
             "MessageID" : self.MessageID
         }
 
+    """ API URL """
+    @property
+    def BuildAPIURL(self):
+
+        url = self.APIURL+"/get/result"
+
+        if self.AuthToken :
+            url = f"{url}/{self.MessageID}"
+
+        return url
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
         
         try:
-            r = requests.post(self.APIURL+"/get/result", data=json.dumps(self.APIData), headers=self.APIHeaders)
+            if self.AuthToken :
+                r = requests.get(self.BuildAPIURL, headers=self.APIHeaders)
+            else :
+                r = requests.post(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return ResultRequestResult(response=r)
@@ -52,11 +66,13 @@ class Result(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return ResultRequestResult(error="Missing Sender")
-        
-        if not self.APIKey :
-            return ResultRequestResult(error="Missing APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return ResultRequestResult(error="Missing Sender")
+            
+            if not self.APIKey :
+                return ResultRequestResult(error="Missing APIKey")
         
         if not self.MessageID:
             return ResultRequestResult(error="Missing MessageID")
@@ -69,11 +85,13 @@ class Result(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return ResultRequestResult(error="Missing Sender")
-        
-        if not self.APIKey :
-            return ResultRequestResult(error="Missing APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return ResultRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return ResultRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return ResultRequestResult(error="Missing MessageID")
@@ -84,4 +102,8 @@ class Result(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'Result(AuthToken=' + self.AuthToken + ')'
+
         return 'Result(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
