@@ -8,6 +8,11 @@ from tnzapi.base import SMSReceivedResult
 class SMSReceived(Common):
 
     TimePeriod  = 1440
+    DateFrom    = None
+    DateTo      = None
+
+    RecordsPerPage  = 100
+    Page            = 1
 
     """ Constructor """
     def __init__(self, kwargs):
@@ -26,23 +31,54 @@ class SMSReceived(Common):
             if key == "TimePeriod":
                 self.TimePeriod = value
 
+            if key == "DateFrom":
+                self.DateFrom = value
+
+            if key == "DateTo":
+                self.DateTo = value
+
+            if key == "RecordsPerPage":
+                self.RecordsPerPage = value
+
+            if key == "Page":
+                self.Page = value
+
+
+
     """ API Data """
     @property
     def APIData(self):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "APIVersion": self.APIVersion,
-            "Type": "SMSReceived",
             "TimePeriod" : self.TimePeriod
         }
 
+    """ API URL """
+    @property
+    def BuildAPIURL(self):
+
+        url = self.APIURL+"/get/sms/received"
+
+        if self.AuthToken :
+
+            if self.DateFrom and self.DateTo:
+                url = f"{url}?dateFrom={self.DateFrom}&dateTo={self.DateTo}&recordPerPage={self.RecordsPerPage}&page={self.Page}"
+            else :
+                url = f"{url}?timePeriod={self.TimePeriod}&recordPerPage={self.RecordsPerPage}&page={self.Page}"
+
+        return url
+
 
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
 
         try:
-            r = requests.post(self.APIURL+"/get/sms/received", data=json.dumps(self.APIData), headers=self.APIHeaders)
+            if self.AuthToken :
+                r = requests.get(self.BuildAPIURL, headers=self.APIHeaders)
+            else :
+                r = requests.post(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
+
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return SMSReceivedResult(response=r)
@@ -63,14 +99,16 @@ class SMSReceived(Common):
             self.__init__(kwargs)
         
         """ Checking validity """
-        if not self.Sender :
-            return SMSReceivedResult(error="Missing Sender")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return SMSReceivedResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SMSReceivedResult(error="Missing AuthToken")
         
-        if not self.APIKey :
-            return SMSReceivedResult(error="Missing APIKey")
-        
-        if not self.MessageID:
-            return SMSReceivedResult(error="Missing MessageID")
+        if not self.TimePeriod:
+            return SMSReceivedResult(error="Missing TimePeriod")
         
         return self.__PostMessage()
 
@@ -81,14 +119,17 @@ class SMSReceived(Common):
             self.__init__(kwargs)
         
         """ Checking validity """
-        if not self.Sender :
-            return SMSReceivedResult(error="Missing Sender")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return SMSReceivedResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SMSReceivedResult(error="Missing AuthToken")
         
-        if not self.APIKey :
-            return SMSReceivedResult(error="Missing APIKey")
-        
-        if not self.MessageID:
-            return SMSReceivedResult(error="Missing MessageID")
+        if not self.TimePeriod:
+
+            return SMSReceivedResult(error="Missing TimePeriod")
         
         return await asyncio.create_task(self.__PostMessageAsync())
 
@@ -96,4 +137,8 @@ class SMSReceived(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'SMSReceived(AuthToken=' + self.AuthToken + ')'
+
         return 'SMSReceived(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
