@@ -25,16 +25,28 @@ class SMSReply(Common):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "APIVersion": self.APIVersion,
-            "Type": "SMSReply",
             "MessageID" : self.MessageID
         }
 
+    """ API URL """
+    @property
+    def BuildAPIURL(self):
+
+        url = self.APIURL+"/get/sms/reply"
+
+        if self.AuthToken :
+            url = f"{url}/{self.MessageID}"
+
+        return url
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
 
         try:
-            r = requests.post(self.APIURL+"/get/sms/reply", data=json.dumps(self.APIData), headers=self.APIHeaders)
+            if self.AuthToken :
+                r = requests.get(self.BuildAPIURL, headers=self.APIHeaders)
+            else :
+                r = requests.post(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return SMSReplyResult(response=r)
@@ -55,11 +67,13 @@ class SMSReply(Common):
             self.__init__(kwargs)
 
         """ Checking validity """
-        if not self.Sender :
-            return SMSReplyResult(error="Missing Sender")
-        
-        if not self.APIKey :
-            return SMSReplyResult(error="Missing APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return SMSReplyResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SMSReplyResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SMSReplyResult(error="Missing MessageID")
@@ -73,11 +87,13 @@ class SMSReply(Common):
             self.__init__(kwargs)
         
         """ Checking validity """
-        if not self.Sender :
-            return SMSReplyResult(error="Missing Sender")
-        
-        if not self.APIKey :
-            return SMSReplyResult(error="Missing APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return SMSReplyResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SMSReplyResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SMSReplyResult(error="Missing MessageID")
@@ -88,4 +104,8 @@ class SMSReply(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'SMSReply(AuthToken=' + self.AuthToken + ')'
+
         return 'SMSReply(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
