@@ -25,16 +25,28 @@ class Status(Common):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "APIVersion": self.APIVersion,
-            "Type": "Status",
             "MessageID" : self.MessageID
         }
 
+    """ API URL """
+    @property
+    def BuildAPIURL(self):
+
+        url = self.APIURL+"/get/status"
+
+        if self.AuthToken :
+            url = f"{url}/{self.MessageID}"
+
+        return url
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
 
         try:
-            r = requests.post(self.APIURL+"/get/status", data=json.dumps(self.APIData), headers=self.APIHeaders)
+            if self.AuthToken :
+                r = requests.get(self.BuildAPIURL, headers=self.APIHeaders)
+            else :
+                r = requests.post(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return StatusRequestResult(response=r)
@@ -54,11 +66,13 @@ class Status(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return StatusRequestResult(error="Missing Sender")
-        
-        if not self.APIKey :
-            return StatusRequestResult(error="Missing APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return StatusRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return StatusRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return StatusRequestResult(error="Missing MessageID")
@@ -71,11 +85,13 @@ class Status(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return StatusRequestResult(error="Missing Sender")
-        
-        if not self.APIKey :
-            return StatusRequestResult(error="Missing APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return StatusRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return StatusRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return StatusRequestResult(error="Missing MessageID")
@@ -86,4 +102,8 @@ class Status(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'Status(AuthToken=' + self.AuthToken + ')'
+
         return 'Status(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
