@@ -64,14 +64,8 @@ class Email(Common):
 
     """ API Data """
     @property
-    def APIData(self):
+    def APIMessageData(self):
         return {
-            "Sender": self.Sender,
-            "APIKey": self.APIKey,
-            "MessageType": "Email",
-            "APIVersion": self.APIVersion,
-            "MessageData" :
-            {
                 "Mode": self.SendMode,
                 "MessageID" : self.MessageID,
                 "ErrorEmailNotify": self.ErrorEmailNotify,
@@ -93,9 +87,28 @@ class Email(Common):
                 "MessageHTML": self.MessageHTML,
                 "Destinations" : self.Recipients,
                 "Files": self.Attachments
-            }
         }
 
+    @property
+    def APIDataWithSender(self):
+        return {
+            "Sender": self.Sender,
+            "APIKey": self.APIKey,
+            "MessageData" : self.APIMessageData
+        }
+    
+    @property
+    def APIDataWithAuthToken(self):
+        return {
+            "MessageData" : self.APIMessageData
+        }
+
+    @property
+    def APIData(self):
+        if self.AuthToken :
+            return self.APIDataWithAuthToken
+        return self.APIDataWithSender
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
 
@@ -120,12 +133,13 @@ class Email(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
+        if not self.AuthToken :
 
-        if not self.Sender :
-            return MessageResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return MessageResult(error="Empty API Key")
+            if not self.Sender :
+                return MessageResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return MessageResult(error="Missing AuthToken")
 
         if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
             return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
@@ -147,11 +161,13 @@ class Email(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return MessageResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return MessageResult(error="Empty API Key")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return MessageResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return MessageResult(error="Missing AuthToken")
 
         if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
             return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
@@ -168,5 +184,9 @@ class Email(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'Email(AuthToken='+self.AuthToken+ ')'
+
         return 'Email(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
     
\ No newline at end of file
