@@ -67,38 +67,51 @@ class Fax(Common):
 
     """ API Data """
     @property
-    def APIData(self):
+    def APIMessageData(self):
+        return {
+            "Mode": self.SendMode,
+            "MessageID" : self.MessageID,
+            
+            "ErrorEmailNotify": self.ErrorEmailNotify,
+            "WebhookCallbackURL": self.WebhookCallbackURL,
+            "WebhookCallbackFormat": self.WebhookCallbackFormat,
+
+            "Reference": self.Reference,
+            "SendTime": self.SendTime,
+            "TimeZone": self.Timezone,
+            "SubAccount": self.SubAccount,
+            "Department": self.Department,
+            "ChargeCode": self.ChargeCode,
+            "Resolution": self.Resolution,
+            "CSID": self.CSID,
+            "StampFormat": self.StampFormat,
+            "WatermarkFolder": self.WatermarkFolder,
+            "WatermarkFirstPage": self.WatermarkFirstPage,
+            "WatermarkAllPages": self.WatermarkAllPages,
+            "Destinations" : self.Recipients,
+            "Files": self.Attachments
+        }
+
+    @property
+    def APIDataWithSender(self):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "MessageType": "Fax",
-            "APIVersion": self.APIVersion,
-            "MessageData" :
-            {
-                "Mode": self.SendMode,
-                "MessageID" : self.MessageID,
-                
-                "ErrorEmailNotify": self.ErrorEmailNotify,
-                "WebhookCallbackURL": self.WebhookCallbackURL,
-                "WebhookCallbackFormat": self.WebhookCallbackFormat,
-
-                "Reference": self.Reference,
-                "SendTime": self.SendTime,
-                "TimeZone": self.Timezone,
-                "SubAccount": self.SubAccount,
-                "Department": self.Department,
-                "ChargeCode": self.ChargeCode,
-                "Resolution": self.Resolution,
-                "CSID": self.CSID,
-                "StampFormat": self.StampFormat,
-                "WatermarkFolder": self.WatermarkFolder,
-                "WatermarkFirstPage": self.WatermarkFirstPage,
-                "WatermarkAllPages": self.WatermarkAllPages,
-                "Destinations" : self.Recipients,
-                "Files": self.Attachments
-            }
+            "MessageData" : self.APIMessageData
         }
 
+    @property
+    def APIDataWithAuthToken(self):
+        return {
+            "MessageData" : self.APIMessageData
+        }
+
+    @property
+    def APIData(self):
+        if self.AuthToken :
+            return self.APIDataWithAuthToken
+        return self.APIDataWithSender
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
 
@@ -123,11 +136,13 @@ class Fax(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return MessageResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return MessageResult(error="Empty APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return MessageResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return MessageResult(error="Missing AuthToken")
 
         if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
             return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
@@ -146,11 +161,13 @@ class Fax(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return MessageResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return MessageResult(error="Empty APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return MessageResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return MessageResult(error="Missing AuthToken")
 
         if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
             return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
@@ -167,4 +184,8 @@ class Fax(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'Fax(AuthToken=' + self.AuthToken + ')'
+
         return 'Fax(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
