@@ -7,10 +7,10 @@ from tnzapi.base import MessageResult
 
 class SMS(Common):
     
-    FromNumber      = ""
-    SMSEmailReply   = ""
-    ForceGSMChars	= False
-    MessageText     = ""
+    FromNumber          = ""
+    SMSEmailReply       = ""
+    CharacterConversion	= False
+    MessageText         = ""
 
     """ Constructor """
     def __init__(self, kwargs):
@@ -21,10 +21,10 @@ class SMS(Common):
 
     """ Destructor """
     def __del__(self):
-        self.FromNumber     = ""
-        self.SMSEmailReply  = ""
-        self.ForceGSMChars  = False
-        self.MessageText    = ""
+        self.FromNumber             = ""
+        self.SMSEmailReply          = ""
+        self.CharacterConversion    = False
+        self.MessageText            = ""
 
     """ Update Data """
     def SetArgsChild(self, kwargs):
@@ -39,48 +39,60 @@ class SMS(Common):
             if key == "SMSEmailReply":
                 self.SMSEmailReply = value
 
-            if key == "ForceGSMChars":
-                self.ForceGSMChars = value
+            if key == "CharacterConversion":
+                self.CharacterConversion = value
             
             if key == "MessageText":
                 self.MessageText = value
 
     """ API Data """
     @property
-    def APIData(self):
+    def APIMessageData(self):
+        return {
+            "Mode": self.SendMode,
+            "MessageID" : self.MessageID,
+
+            "ErrorEmailNotify": self.ErrorEmailNotify,
+            "WebhookCallbackURL": self.WebhookCallbackURL,
+            "WebhookCallbackFormat": self.WebhookCallbackFormat,
+
+            "Reference": self.Reference,
+            "SendTime": self.SendTime,
+            "TimeZone": self.Timezone,
+            "SubAccount": self.SubAccount,
+            "Department": self.Department,
+            "ChargeCode": self.ChargeCode,
+            "FromNumber": self.FromNumber,
+            "SMSEmailReply": self.SMSEmailReply,
+            "CharacterConversion": self.CharacterConversion,
+            "Message": self.MessageText,
+            "Destinations" : self.Recipients,
+            "Files": self.Attachments
+        }
+
+    @property
+    def APIDataWithSender(self):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "MessageType": "SMS",
-            "APIVersion": self.APIVersion,
-
-            "MessageData" :
-            {
-                "Mode": self.SendMode,
-                "MessageID" : self.MessageID,
-
-                "ErrorEmailNotify": self.ErrorEmailNotify,
-                "WebhookCallbackURL": self.WebhookCallbackURL,
-                "WebhookCallbackFormat": self.WebhookCallbackFormat,
-
-                "Reference": self.Reference,
-                "SendTime": self.SendTime,
-                "TimeZone": self.Timezone,
-                "SubAccount": self.SubAccount,
-                "Department": self.Department,
-                "ChargeCode": self.ChargeCode,
-                "FromNumber": self.FromNumber,
-                "SMSEmailReply": self.SMSEmailReply,
-                "ForceGSMChars": self.ForceGSMChars,
-                "Message": self.MessageText,
-                "Destinations" : self.Recipients,
-                "Files": self.Attachments
-            }
+            "MessageData" : self.APIMessageData
         }
 
+    @property
+    def APIDataWithAuthToken(self):
+        return {
+            "MessageData" : self.APIMessageData
+        }
+
+    @property
+    def APIData(self):
+        if self.AuthToken :
+            return self.APIDataWithAuthToken
+        return self.APIDataWithSender
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
-
+        
         try:
             r = requests.post(self.APIURL+"/send/sms", data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
@@ -97,16 +109,26 @@ class SMS(Common):
         return self.__PostMessage()
 
     """ Function to send message """
+
+    """
+    def SendMessage(self, **kwargs):
+        super().SetArgsCommon(kwargs)
+        self.SetArgsSMS(kwargs)
+        ...
+    """
+    
     def SendMessage(self, **kwargs):
 
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return MessageResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return MessageResult(error="Empty API Key")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return MessageResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return MessageResult(error="Missing AuthToken")
 
         if self.WebhookCallbackURL :
 
@@ -130,11 +152,13 @@ class SMS(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return MessageResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return MessageResult(error="Empty API Key")
+        if not self.AuthToken:
+
+            if not self.Sender :
+                return MessageResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return MessageResult(error="Missing AuthToken")
 
         if self.WebhookCallbackURL :
 
@@ -156,4 +180,7 @@ class SMS(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+        if self.AuthToken:
+            return 'SMS(AuthToken='+self.AuthToken+')'
+        
         return 'SMS(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
