@@ -103,48 +103,61 @@ class Voice(Common):
 
     """ API Data """
     @property
-    def APIData(self):
+    def APIMessageData(self):
+        return {
+            "Mode": self.SendMode,
+            "MessageID" : self.MessageID,
+
+            "ErrorEmailNotify": self.ErrorEmailNotify,
+            "WebhookCallbackURL": self.WebhookCallbackURL,
+            "WebhookCallbackFormat": self.WebhookCallbackFormat,
+            
+            "Reference": self.Reference,
+            "SendTime": self.SendTime,
+            "TimeZone": self.Timezone,
+            "SubAccount": self.SubAccount,
+            "BillingAccount": self.BillingAccount,
+            "Department": self.Department,
+            "ChargeCode": self.ChargeCode,
+            "ReportTo": self.ReportTo,
+
+            "CallerID": self.CallerID,
+
+            "MessageToPeople": self.MessageToPeople,
+            "MessageToAnswerphones": self.MessageToAnswerPhones,
+            "CallRouteMessageToPeople": self.CallRouteMessageToPeople,
+            "CallRouteMessageToOperators": self.CallRouteMessageToOperators,
+            "CallRouteMessageOnWrongKey": self.CallRouteMessageOnWrongKey,
+
+            "Keypads": self.Keypads,
+
+            "NumberOfOperators": self.NumberOfOperators,
+            "RetryAttempts": self.RetryAttempts,
+            "RetryPeriod": self.RetryPeriod,
+            "Options": self.Options,
+
+            "Destinations" : self.Recipients
+        }
+
+    @property
+    def APIDataWithSender(self):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "MessageType": "Voice",
-            "APIVersion": self.APIVersion,
-            "MessageData" :
-            {
-                "Mode": self.SendMode,
-                "MessageID" : self.MessageID,
-
-                "ErrorEmailNotify": self.ErrorEmailNotify,
-                "WebhookCallbackURL": self.WebhookCallbackURL,
-                "WebhookCallbackFormat": self.WebhookCallbackFormat,
-                
-                "Reference": self.Reference,
-                "SendTime": self.SendTime,
-                "TimeZone": self.Timezone,
-                "SubAccount": self.SubAccount,
-                "BillingAccount": self.BillingAccount,
-                "Department": self.Department,
-                "ChargeCode": self.ChargeCode,
-                "ReportTo": self.ReportTo,
-
-                "CallerID": self.CallerID,
-
-                "MessageToPeople": self.MessageToPeople,
-                "MessageToAnswerphones": self.MessageToAnswerPhones,
-                "CallRouteMessageToPeople": self.CallRouteMessageToPeople,
-                "CallRouteMessageToOperators": self.CallRouteMessageToOperators,
-                "CallRouteMessageOnWrongKey": self.CallRouteMessageOnWrongKey,
-
-                "Keypads": self.Keypads,
-
-                "NumberOfOperators": self.NumberOfOperators,
-                "RetryAttempts": self.RetryAttempts,
-                "RetryPeriod": self.RetryPeriod,
-                "Options": self.Options,
-
-                "Destinations" : self.Recipients
-            }
+            "MessageData" : self.APIMessageData
         }
+    
+    @property
+    def APIDataWithAuthToken(self):
+        return {
+            "MessageData" : self.APIMessageData
+        }
+
+    @property
+    def APIData(self):
+        if self.AuthToken :
+            return self.APIDataWithAuthToken
+        return self.APIDataWithSender
 
     """ Add Message Data """
     def AddMessageData(self, type, file):
@@ -170,8 +183,8 @@ class Voice(Common):
 
         keypad = Keypad(**kwargs)
 
-        if keypad.Play == "" and keypad.PlayFile != "":
-            keypad.Play = base64.b64encode(open(keypad.PlayFile,"rb").read()).decode("utf-8")
+        if keypad.PlayFile != "":
+            keypad.PlayFile = base64.b64encode(open(keypad.PlayFile,"rb").read()).decode("utf-8")
 
         self.Keypads.append(
         {
@@ -206,11 +219,12 @@ class Voice(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return MessageResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return MessageResult(error="Empty APIKey")
+        if not self.AuthToken :
+            if not self.Sender :
+                return MessageResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return MessageResult(error="Missing AuthToken")
 
         if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
             return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
@@ -237,11 +251,13 @@ class Voice(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return MessageResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return MessageResult(error="Empty APIKey")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return MessageResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return MessageResult(error="Missing AuthToken")
 
         if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
             return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
@@ -266,4 +282,8 @@ class Voice(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if not self.AuthToken :
+            return 'Voice(AuthToken=' + self.AuthToken + ')'
+
         return 'Voice(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
