@@ -21,20 +21,41 @@ class Abort(Common):
 
     """ API Data """
     @property
-    def APIData(self):
+    def APIDataWithSender(self):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "APIVersion": self.APIVersion,
-            "Type": "Abort",
             "MessageID" : self.MessageID
         }
 
+    @property
+    def APIDataWithAuthToken(self):
+        return {}
+
+    @property
+    def APIData(self):
+        if self.AuthToken :
+            return self.APIDataWithAuthToken
+        return self.APIDataWithSender
+
+    @property
+    def BuildAPIURL(self):
+
+        url = self.APIURL+"/set/abort"
+
+        if self.AuthToken :
+            url = f"{url}/{self.MessageID}"
+
+        return url
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
 
         try:
-            r = requests.post(self.APIURL+"/set/abort", data=json.dumps(self.APIData), headers=self.APIHeaders)
+            if self.AuthToken :
+                r = requests.patch(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
+            else :
+                r = requests.post(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return SetRequestResult(response=r)
@@ -54,11 +75,13 @@ class Abort(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return SetRequestResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return SetRequestResult(error="Empty API Key")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return SetRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SetRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SetRequestResult(error="Empty Message ID")
@@ -71,11 +94,13 @@ class Abort(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return SetRequestResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return SetRequestResult(error="Empty API Key")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return SetRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SetRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SetRequestResult(error="Empty Message ID")
@@ -86,4 +111,8 @@ class Abort(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'Abort(AuthToken='+self.AuthToken+ ')'
+
         return 'Abort(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
