@@ -28,21 +28,44 @@ class Pacing(Common):
 
     """ API Data """
     @property
-    def APIData(self):
+    def APIDataWithSender(self):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "APIVersion": self.APIVersion,
-            "Type": "Pacing",
             "MessageID" : self.MessageID,
             "NumberOfOperators": self.NumberOfOperators
         }
 
+    @property
+    def APIDataWithAuthToken(self):
+        return {
+            "NumberOfOperators": self.NumberOfOperators
+        }
+
+    @property
+    def APIData(self):
+        if self.AuthToken :
+            return self.APIDataWithAuthToken
+        return self.APIDataWithSender
+
+    @property
+    def BuildAPIURL(self):
+
+        url = self.APIURL+"/set/pacing"
+
+        if self.AuthToken :
+            url = f"{url}/{self.MessageID}"
+
+        return url
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
 
         try:
-            r = requests.post(self.APIURL+"/set/pacing", data=json.dumps(self.APIData), headers=self.APIHeaders)
+            if self.AuthToken :
+                r = requests.patch(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
+            else :
+                r = requests.post(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return SetRequestResult(response=r)
@@ -62,11 +85,12 @@ class Pacing(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return SetRequestResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return SetRequestResult(error="Empty API Key")
+        if not self.AuthToken :
+            if not self.Sender :
+                return SetRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SetRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SetRequestResult(error="Empty Message ID")
@@ -81,13 +105,14 @@ class Pacing(Common):
 
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
+        
+        if not self.AuthToken :
+            if not self.Sender :
+                return SetRequestResult(error="Missing AuthToken")
 
-        if not self.Sender :
-            return SetRequestResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return SetRequestResult(error="Empty API Key")
-        
+            if not self.APIKey :
+                return SetRequestResult(error="Missing AuthToken")
+            
         if not self.MessageID:
             return SetRequestResult(error="Empty Message ID")
 
@@ -100,4 +125,8 @@ class Pacing(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'Pacing(AuthToken=' + self.AuthToken + ')'
+
         return 'Pacing(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
