@@ -32,21 +32,44 @@ class Reschedule(Common):
 
     """ API Data """
     @property
-    def APIData(self):
+    def APIDataWithSender(self):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "APIVersion": self.APIVersion,
-            "Type": "Reschedule",
             "MessageID" : self.MessageID,
             "SendTime": self.SendTime
         }
 
+    @property
+    def APIDataWithAuthToken(self):
+        return {
+            "SendTime": self.SendTime
+        }
+
+    @property
+    def APIData(self):
+        if self.AuthToken :
+            return self.APIDataWithAuthToken
+        return self.APIDataWithSender
+
+    @property
+    def BuildAPIURL(self):
+
+        url = self.APIURL+"/set/reschedule"
+
+        if self.AuthToken :
+            url = f"{url}/{self.MessageID}"
+
+        return url
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
 
         try:
-            r = requests.post(self.APIURL+"/set/reschedule", data=json.dumps(self.APIData), headers=self.APIHeaders)
+            if self.AuthToken :
+                r = requests.patch(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
+            else :
+                r = requests.post(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return SetRequestResult(response=r)
@@ -66,11 +89,12 @@ class Reschedule(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return SetRequestResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return SetRequestResult(error="Empty API Key")
+        if not self.AuthToken :
+            if not self.Sender :
+                return SetRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SetRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SetRequestResult(error="Empty Message ID")
@@ -86,11 +110,12 @@ class Reschedule(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return SetRequestResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return SetRequestResult(error="Empty API Key")
+        if not self.AuthToken :
+            if not self.Sender :
+                return SetRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SetRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SetRequestResult(error="Empty Message ID")
@@ -104,4 +129,8 @@ class Reschedule(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'Reschedule(AuthToken='+self.AuthToken+ ')'
+
         return 'Reschedule(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
