@@ -31,21 +31,44 @@ class Resubmit(Common):
 
     """ API Data """
     @property
-    def APIData(self):
+    def APIDataWithSender(self):
         return {
             "Sender": self.Sender,
             "APIKey": self.APIKey,
-            "APIVersion": self.APIVersion,
-            "Type": "Resubmit",
             "MessageID" : self.MessageID,
             "SendTime": self.SendTime
         }
 
+    @property
+    def APIDataWithAuthToken(self):
+        return {
+            "SendTime": self.SendTime
+        }
+
+    @property
+    def APIData(self):
+        if self.AuthToken :
+            return self.APIDataWithAuthToken
+        return self.APIDataWithSender
+
+    @property
+    def BuildAPIURL(self):
+
+        url = self.APIURL+"/set/resubmit"
+
+        if self.AuthToken :
+            url = f"{url}/{self.MessageID}"
+
+        return url
+
     """ Private function to POST message to TNZ REST API """
     def __PostMessage(self):
         
         try:
-            r = requests.post(self.APIURL+"/set/resubmit", data=json.dumps(self.APIData), headers=self.APIHeaders)
+            if self.AuthToken :
+                r = requests.patch(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
+            else :
+                r = requests.post(self.BuildAPIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return SetRequestResult(response=r)
@@ -65,11 +88,13 @@ class Resubmit(Common):
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return SetRequestResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return SetRequestResult(error="Empty API Key")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return SetRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SetRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SetRequestResult(error="Empty Message ID")
@@ -77,16 +102,18 @@ class Resubmit(Common):
         return self.__PostMessage()
 
     """ Async Function to send message """
-    async def SendRequestAsync(self,**kwargs):
+    async def SendRequestAsync(self, **kwargs):
 
         if kwargs != None and len(kwargs) > 0:
             self.__init__(kwargs)
 
-        if not self.Sender :
-            return SetRequestResult(error="Empty Sender")
-        
-        if not self.APIKey :
-            return SetRequestResult(error="Empty API Key")
+        if not self.AuthToken :
+
+            if not self.Sender :
+                return SetRequestResult(error="Missing AuthToken")
+            
+            if not self.APIKey :
+                return SetRequestResult(error="Missing AuthToken")
         
         if not self.MessageID:
             return SetRequestResult(error="Empty Message ID")
@@ -97,4 +124,8 @@ class Resubmit(Common):
         return self.__pretty__(self.APIData)
 
     def __str__(self):
+
+        if self.AuthToken :
+            return 'Resubmit(AuthToken='+self.AuthToken+')'
+
         return 'Resubmit(Sender='+self.Sender+', APIKey='+str(self.APIKey)+ ')'
\ No newline at end of file
